@@ -208,7 +208,22 @@ class Route53ToAlb(
         :summary: Constructs a new instance of the Route53ToAlb class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Route53ToAlb.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                public_api: builtins.bool,
+                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
+                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                load_balancer_props: typing.Any = None,
+                log_alb_access_logs: typing.Optional[builtins.bool] = None,
+                private_hosted_zone_props: typing.Any = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Route53ToAlbProps(
@@ -288,7 +303,20 @@ class Route53ToAlbProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(Route53ToAlbProps.__init__)
+            def stub(
+                *,
+                public_api: builtins.bool,
+                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
+                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                load_balancer_props: typing.Any = None,
+                log_alb_access_logs: typing.Optional[builtins.bool] = None,
+                private_hosted_zone_props: typing.Any = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
             check_type(argname="argument existing_hosted_zone_interface", value=existing_hosted_zone_interface, expected_type=type_hints["existing_hosted_zone_interface"])
